==> spip_3.2.11.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Inserir À',
	'barre_adresse' => 'Endereço',
	'barre_aide' => 'Usar os atalhos tipográficos para refinar o plano da página',
	'barre_alignerdroite' => '[/Alinhar à direita/] o parágrafo',
	'barre_ancres' => 'Gestão das âncoras',
	'barre_barre' => 'Percorrer o texto',
	'barre_bulle' => 'Balão de ajuda',
	'barre_c_cedille_maj' => 'Inserir Ç',
	'barre_cadre' => 'Colocar numa &lt;cadre&gt;caixa de entrada de texto&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracteres especiais',
	'barre_centrer' => '[|Centrar|] o parágrafo',
	'barre_chercher' => 'Procurar & Substituir',
	'barre_clean' => 'Limpar o código de todas as tags HTML',
	'barre_code' => 'Editar um &lt;code&gt;código informático&lt;/code&gt;',
	'barre_desindenter' => 'Não pôr avanço numa lista',
	'barre_e_accent_aigu' => 'Inserir É',
	'barre_e_accent_grave' => 'Inserir È',
	'barre_ea' => 'Inserir æ',
	'barre_ea_maj' => 'Inserir Æ',
	'barre_encadrer' => '[(Enquadrar)] o parágrafo',
	'barre_eo' => 'Inserir œ',
	'barre_eo_maj' => 'Inserir Œ',
	'barre_euro' => 'Inserir o símbolo €',
	'barre_exposant' => 'Por o texto em &lt;sup&gt;superscript&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formatação especial',
	'barre_galerie' => 'Abrir a galeria',
	'barre_gestion_anc_bulle' => 'Balão de ajuda da âncora',
	'barre_gestion_anc_caption' => 'Gestão das âncoras',
	'barre_gestion_anc_cible' => 'Âncora-alvo',
	'barre_gestion_anc_inserer' => 'Converter em âncora',
	'barre_gestion_anc_nom' => 'Nome da âncora',
	'barre_gestion_anc_pointer' => 'Apontar para uma âncora',
	'barre_gestion_caption' => 'Legenda e Resumo',
	'barre_gestion_colonne' => 'Nº de colunas',
	'barre_gestion_cr_casse' => 'Manter maiúsculas e minúsculas',
	'barre_gestion_cr_changercasse' => 'Alterar maiúsculas e minúsculas',
	'barre_gestion_cr_changercassemajuscules' => 'Pôr em maiúsculas',
	'barre_gestion_cr_changercasseminuscules' => 'Pôr em minúsculas',
	'barre_gestion_cr_chercher' => 'Procurar',
	'barre_gestion_cr_entier' => 'Apenas palavras completas',
	'barre_gestion_cr_remplacer' => 'Substituir',
	'barre_gestion_cr_tout' => 'Substituir tudo',
	'barre_gestion_entete' => 'Cabeçalho',
	'barre_gestion_ligne' => 'Nº de linhas',
	'barre_gestion_taille' => 'Tamanho fixo',
	'barre_glossaire' => 'Entrada do [?glossário] (Wikipedia)',
	'barre_gras' => 'Colocar em {{negrito}}',
	'barre_guillemets' => 'Colocar entre « aspas duplas »',
	'barre_guillemets_simples' => 'Colocar entre “aspas simples”',
	'barre_indenter' => 'Pôr avanço numa lista',
	'barre_inserer_cadre' => 'Inserir um código pré-formatado (cadre)',
	'barre_inserer_caracteres' => 'Inserir caracteres especiais',
	'barre_inserer_code' => 'Inserir um código informático (code)',
	'barre_intertitre' => 'Converter em {{{subcabeçalho}}}',
	'barre_italic' => 'Colocar em {itálico}',
	'barre_langue' => 'Idioma abreviado',
	'barre_lien' => 'Transformar em [ligação hipertexto->http://...]',
	'barre_lien_externe' => 'Ligação externa',
	'barre_lien_input' => 'Por favor indique o endereço da sua ligação (pode indicar um endereço Internet na forma http://www.monsite.com, um endereço de e-mail, ou simplesmente o número de um artigo neste sítio).',
	'barre_liste_ol' => 'Colocar em lista numerada',
	'barre_liste_ul' => 'Colocar em lista',
	'barre_lorem_ipsum' => 'Inserir um falso parágrafo',
	'barre_lorem_ipsum_3' => 'Inserir três falsos parágrafos',
	'barre_miseenevidence' => '[*Realçar*] o texto',
	'barre_note' => 'Converter em [[Nota de rodapé]]',
	'barre_paragraphe' => 'Criar um parágrafo',
	'barre_petitescapitales' => 'Colocar o texto em &lt;sc&gt;petites capitales&lt;/sc&gt;',
	'barre_poesie' => 'Editar como uma &lt;poesie&gt;poésie&lt;/poesie&gt;',
	'barre_preview' => 'Modo pré-visualização',
	'barre_quote' => '<quote>Citar uma mensagem</quote>',
	'barre_stats' => 'Exibir as estatísticas do texto',
	'barre_tableau' => 'Inserir/modificar (seleccionar primeiro) uma tabela',

	// C
	'config_info_enregistree' => 'Configuração guardada',

	// E
	'editer' => 'Editar',
	'explication_barre_outils_public' => 'Os scripts CSS e Javascript das barras de ferramentas	(extensão Porte Plume) são carregados no sítio público e permitem utilizar barras de ferramentas em fóruns, crayons públicos ou outros plugins, se a sua respectiva configuração o permitir.',
	'explication_barre_outils_public_2' => 'Pode escolher não carregar estes scripts, para tornar mais leves as páginas públicas.
Assim, em qualquer configuração dos fóruns, crayons ou plugins, nenhuma barra de ferramentas Pena aparecerá automaticamente no sítio público.',

	// I
	'info_barre_outils_public' => 'Barra de ferramentas pública',
	'info_porte_plume_titre' => 'Configurar a barra de ferramentas',

	// L
	'label_barre_outils_public_non' => 'Não carregar os scripts de barras de ferramentas no sítio público.',
	'label_barre_outils_public_oui' => 'Carregar os scripts de barras de ferramentas no sítio público.',

	// V
	'voir' => 'Visualizar'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Inserir À',
	'barre_adresse' => 'Endereço',
	'barre_aide' => 'Usar os atalhos tipográficos para refinar o plano da página',
	'barre_alignerdroite' => '[/Alinhar à direita/] o parágrafo',
	'barre_ancres' => 'Gestão das âncoras',
	'barre_barre' => 'Percorrer o texto',
	'barre_bulle' => 'Balão de ajuda',
	'barre_c_cedille_maj' => 'Inserir Ç',
	'barre_cadre' => 'Colocar numa &lt;cadre&gt;caixa de entrada de texto&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracteres especiais',
	'barre_centrer' => '[|Centrar|] o parágrafo',
	'barre_chercher' => 'Procurar & Substituir',
	'barre_clean' => 'Limpar o código de todas as tags HTML',
	'barre_code' => 'Editar um &lt;code&gt;código informático&lt;/code&gt;',
	'barre_desindenter' => 'Não pôr avanço numa lista',
	'barre_e_accent_aigu' => 'Inserir É',
	'barre_e_accent_grave' => 'Inserir È',
	'barre_ea' => 'Inserir æ',
	'barre_ea_maj' => 'Inserir Æ',
	'barre_encadrer' => '[(Enquadrar)] o parágrafo',
	'barre_eo' => 'Inserir œ',
	'barre_eo_maj' => 'Inserir Œ',
	'barre_euro' => 'Inserir o símbolo €',
	'barre_exposant' => 'Por o texto em &lt;sup&gt;superscript&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formatação especial',
	'barre_galerie' => 'Abrir a galeria',
	'barre_gestion_anc_bulle' => 'Balão de ajuda da âncora',
	'barre_gestion_anc_caption' => 'Gestão das âncoras',
	'barre_gestion_anc_cible' => 'Âncora-alvo',
	'barre_gestion_anc_inserer' => 'Converter em âncora',
	'barre_gestion_anc_nom' => 'Nome da âncora',
	'barre_gestion_anc_pointer' => 'Apontar para uma âncora',
	'barre_gestion_caption' => 'Legenda e Resumo',
	'barre_gestion_colonne' => 'Nº de colunas',
	'barre_gestion_cr_casse' => 'Manter maiúsculas e minúsculas',
	'barre_gestion_cr_changercasse' => 'Alterar maiúsculas e minúsculas',
	'barre_gestion_cr_changercassemajuscules' => 'Pôr em maiúsculas',
	'barre_gestion_cr_changercasseminuscules' => 'Pôr em minúsculas',
	'barre_gestion_cr_chercher' => 'Procurar',
	'barre_gestion_cr_entier' => 'Apenas palavras completas',
	'barre_gestion_cr_remplacer' => 'Substituir',
	'barre_gestion_cr_tout' => 'Substituir tudo',
	'barre_gestion_entete' => 'Cabeçalho',
	'barre_gestion_ligne' => 'Nº de linhas',
	'barre_gestion_taille' => 'Tamanho fixo',
	'barre_glossaire' => 'Entrada do [?glossário] (Wikipedia)',
	'barre_gras' => 'Colocar em {{negrito}}',
	'barre_guillemets' => 'Colocar entre « aspas duplas »',
	'barre_guillemets_simples' => 'Colocar entre “aspas simples”',
	'barre_indenter' => 'Pôr avanço numa lista',
	'barre_inserer_cadre' => 'Inserir um código pré-formatado (cadre)', # MODIF
	'barre_inserer_caracteres' => 'Inserir caracteres especiais',
	'barre_inserer_code' => 'Inserir um código informático (code)', # MODIF
	'barre_intertitre' => 'Converter em {{{subcabeçalho}}}',
	'barre_italic' => 'Colocar em {itálico}',
	'barre_langue' => 'Idioma abreviado',
	'barre_lien' => 'Transformar em [ligação hipertexto->http://...]',
	'barre_lien_externe' => 'Ligação externa',
	'barre_lien_input' => 'Por favor indique o endereço da sua ligação (pode indicar um endereço Internet na forma http://www.monsite.com, um endereço de e-mail, ou simplesmente o número de um artigo neste sítio).',
	'barre_liste_ol' => 'Colocar em lista numerada',
	'barre_liste_ul' => 'Colocar em lista',
	'barre_lorem_ipsum' => 'Inserir um falso parágrafo',
	'barre_lorem_ipsum_3' => 'Inserir três falsos parágrafos',
	'barre_miseenevidence' => '[*Realçar*] o texto',
	'barre_note' => 'Converter em [[Nota de rodapé]]',
	'barre_paragraphe' => 'Criar um parágrafo',
	'barre_petitescapitales' => 'Colocar o texto em &lt;sc&gt;petites capitales&lt;/sc&gt;',
	'barre_poesie' => 'Editar como uma &lt;poesie&gt;poésie&lt;/poesie&gt;',
	'barre_preview' => 'Modo pré-visualização',
	'barre_quote' => '<quote>Citar uma mensagem</quote>',
	'barre_stats' => 'Exibir as estatísticas do texto',
	'barre_tableau' => 'Inserir/modificar (seleccionar primeiro) uma tabela',

	// C
	'config_info_enregistree' => 'Configuração guardada',

	// E
	'editer' => 'Editar',
	'explication_barre_outils_public' => 'Os scripts CSS e Javascript das barras de ferramentas	(extensão Porte Plume) são carregados no sítio público e permitem utilizar barras de ferramentas em fóruns, crayons públicos ou outros plugins, se a sua respectiva configuração o permitir.',
	'explication_barre_outils_public_2' => 'Pode escolher não carregar estes scripts, para tornar mais leves as páginas públicas.
Assim, em qualquer configuração dos fóruns, crayons ou plugins, nenhuma barra de ferramentas Pena aparecerá automaticamente no sítio público.',

	// I
	'info_barre_outils_public' => 'Barra de ferramentas pública',
	'info_porte_plume_titre' => 'Configurar a barra de ferramentas',

	// L
	'label_barre_outils_public_non' => 'Não carregar os scripts de barras de ferramentas no sítio público.',
	'label_barre_outils_public_oui' => 'Carregar os scripts de barras de ferramentas no sítio público.',

	// V
	'voir' => 'Visualizar'
);
